==> support-api-1.2.2.141-standard-20240509.025448-1-sources.jar: com/elitesland/support/provider/org/service/OrgStoreRpcService.java <==
package com.elitesland.support.provider.org.service;

import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.common.base.PagingVO;
import com.elitesland.support.provider.Application;
import com.elitesland.support.provider.org.dto.OrgStoreDetailRpcDTO;
import com.elitesland.support.provider.org.dto.OrgStoreRpcDTO;
import com.elitesland.support.provider.org.dto.OrgStoreWhDTO;
import com.elitesland.support.provider.org.param.OrgStoreRpcParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@FeignClient(name = Application.NAME, path = Application.PATH + OrgStoreRpcService.PATH)
@Validated
public interface OrgStoreRpcService {
    String PATH = "/orgStoreRpc";

    @GetMapping("/{id}")
    OrgStoreDetailRpcDTO get(@PathVariable("id") Long id);

    @GetMapping("/getByCode")
    OrgStoreDetailRpcDTO getByCode(@RequestParam("storeCode") String storeCode);

    @PostMapping("/storeWh/codes")
    ApiResult<List<OrgStoreWhDTO>> listWhByCode(@RequestBody List<String> storeCodes);

    @PostMapping("/queryByIds")
    List<OrgStoreDetailRpcDTO> queryByIds(@RequestBody List<Long> ids);

    @PostMapping("/queryByStoreCodes")
    List<OrgStoreDetailRpcDTO> queryByStoreCodes(@RequestBody List<String> storeCodes);


    @PostMapping("/appSearch")
    List<OrgStoreRpcDTO> appSearch(@RequestBody OrgStoreRpcParam param);

    @PostMapping("/pageStoreQuery")
    PagingVO<OrgStoreRpcDTO> rpcStoreQuery(@RequestBody OrgStoreRpcParam param);


}

==> support-api-1.2.2.197-standard-20240731.054322-1-sources.jar: com/elitesland/support/provider/org/service/OrgStoreRpcService.java <==
package com.elitesland.support.provider.org.service;

import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.common.base.PagingVO;
import com.elitesland.support.provider.Application;
import com.elitesland.support.provider.org.dto.OrgStoreBaseRpcDTO;
import com.elitesland.support.provider.org.dto.OrgStoreDetailRpcDTO;
import com.elitesland.support.provider.org.dto.OrgStoreRpcDTO;
import com.elitesland.support.provider.org.dto.OrgStoreWhDTO;
import com.elitesland.support.provider.org.param.OrgStoreBaseRpcParam;
import com.elitesland.support.provider.org.param.OrgStoreRpcParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@FeignClient(name = Application.NAME, path = Application.PATH + OrgStoreRpcService.PATH)
@Validated
public interface OrgStoreRpcService {
    String PATH = "/orgStoreRpc";

    @GetMapping("/{id}")
    OrgStoreDetailRpcDTO get(@PathVariable("id") Long id);

    @GetMapping("/getByCode")
    OrgStoreDetailRpcDTO getByCode(@RequestParam("storeCode") String storeCode);

    @PostMapping("/storeWh/codes")
    ApiResult<List<OrgStoreWhDTO>> listWhByCode(@RequestBody List<String> storeCodes);

    @PostMapping("/queryByIds")
    List<OrgStoreDetailRpcDTO> queryByIds(@RequestBody List<Long> ids);

    @PostMapping("/queryByStoreCodes")
    List<OrgStoreDetailRpcDTO> queryByStoreCodes(@RequestBody List<String> storeCodes);


    @PostMapping("/appSearch")
    List<OrgStoreRpcDTO> appSearch(@RequestBody OrgStoreRpcParam param);

    @PostMapping("/pageStoreQuery")
    PagingVO<OrgStoreRpcDTO> rpcStoreQuery(@RequestBody OrgStoreRpcParam param);

    /**
     * 查询门店基础信息
     * @param baseRpcParam
     * @return
     */
    @PostMapping("/findOrgStoreBaseByParam")
    ApiResult<List<OrgStoreBaseRpcDTO>> findOrgStoreBaseByParam(@RequestBody OrgStoreBaseRpcParam baseRpcParam);
}
